CommsAttachment class

Constructors

CommsAttachment({int? width, int? height, String? fileKey, required String fileUrl, String? thumbnailUrl, String? blurHash, String? fileName, int? fileSize, required String fileType, String? contentType})
CommsAttachment.fromJson(Map<String, dynamic> json)
factory

Properties

blurHash String?
final
contentType String?
final
fileKey String?
final
fileName String?
final
fileSize int?
final
fileType String
final
fileUrl String
final
hashCode int
The hash code for this object.
no setterinherited
height int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnailUrl String?
final
width int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited