CommsDeliveryInfo class
Constructors
- CommsDeliveryInfo({required int userId, DateTime? deliveredAt})
-
CommsDeliveryInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- deliveredAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited