CommsGroup class

Constructors

CommsGroup({required int id, required String groupType, required String name, required int driverUserId, required bool allowReplies, required String status, DateTime? createdAt, DateTime? updatedAt, required List<CommsParticipant> participants, CommsUser? driverUser, CommsUser? creator, CommsMessage? lastMessage, int unreadCount = 0})
CommsGroup.fromJson(Map<String, dynamic> json)
factory

Properties

allowReplies bool
final
createdAt DateTime?
final
creator CommsUser?
final
driverUser CommsUser?
final
driverUserId int
final
groupType String
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
lastMessage CommsMessage?
final
name String
final
participants List<CommsParticipant>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
unreadCount int
final
updatedAt DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited