CommsMessage class

Constructors

CommsMessage({required int id, int? groupId, int? senderId, required String messageContent, DateTime? createdAt, DateTime? updatedAt, CommsUser? sender, List<CommsReadInfo> readInfo = const [], List<CommsDeliveryInfo> deliveryInfo = const [], String overallStatus = 'sent', List<CommsAttachment> attachments = const [], List reactions = const [], CommsMessage? replyTo, List mentions = const [], int? messageId, String? content, CommsMessage? lastMessage})
CommsMessage.fromJson(Map<String, dynamic> json)
factory

Properties

attachments List<CommsAttachment>
final
content String?
final
createdAt DateTime?
final
deliveryInfo List<CommsDeliveryInfo>
final
groupId int?
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
lastMessage CommsMessage?
final
mentions List
final
messageContent String
final
messageId int?
final
overallStatus String
final
reactions List
final
readInfo List<CommsReadInfo>
final
replyTo CommsMessage?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender CommsUser?
final
senderId int?
final
updatedAt DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited