CommsParticipant class

Constructors

CommsParticipant({required int id, required int groupId, required int userId, int? lastReadMessageId, required int unreadCount, Map<String, dynamic>? taggedMessage})
CommsParticipant.fromJson(Map<String, dynamic> json)
factory

Properties

groupId int
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
lastReadMessageId int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taggedMessage Map<String, dynamic>?
final
unreadCount int
final
userId int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited