CommsUser class

Constructors

CommsUser({required int id, required String username, required String email, required String phone, String? profilePic, required int roleId, required bool isActive, CommsRole? role})
CommsUser.fromJson(Map<String, dynamic> json)
factory

Properties

email String
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
isActive bool
final
phone String
final
profilePic String?
final
role CommsRole?
final
roleId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited