forceShowBackButton property
Alias / convenience property for showBackButton. When true, forces the back button to be visible.
Implementation
final bool? forceShowBackButton;
Alias / convenience property for showBackButton. When true, forces the back button to be visible.
final bool? forceShowBackButton;