onLoadMoreMessages property
Callback triggered when user scrolls to the top of the conversation.
Implementation
final Future<void> Function()? onLoadMoreMessages;
Callback triggered when user scrolls to the top of the conversation.
final Future<void> Function()? onLoadMoreMessages;