MessageBox class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MessageBox
Constructors
-
MessageBox({Key? key, required TextEditingController messageController, required FocusNode focusNode, required bool showEmojiPicker, required String title, required VoidCallback onSendMessage, required VoidCallback onToggleEmojiPicker, Map<
String, dynamic> ? taggedMessage, VoidCallback? onCancelTag, List<String> ? mentionableUsers, ValueChanged<List< ? onMediaPicked, bool? showMediaPicker = true})File> > -
const
Properties
- focusNode → FocusNode
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
mentionableUsers
→ List<
String> ? -
final
- messageController → TextEditingController
-
final
- onCancelTag → VoidCallback?
-
final
-
onMediaPicked
→ ValueChanged<
List< ?File> > -
final
- onSendMessage → VoidCallback
-
final
- onToggleEmojiPicker → VoidCallback
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showEmojiPicker → bool
-
final
- showMediaPicker → bool?
-
final
-
taggedMessage
→ Map<
String, dynamic> ? -
final
- title → String
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MessageBox> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited